
import java.awt.Color;
import java.awt.Graphics;
import java.util.Random;

import javax.swing.JPanel;

/**
 * Komponenta uživatelského rozhraní zobrazující půlkruh pomocí
 * náhodné barvy.
 */
public class Kolac extends JPanel {

    /**
     * Pole hodnot, podle kterych se bude vykreslovat graf
     */
    private int[] hodnoty;
    /**
     * Koeficient, kterym se prenasobuje hodnota aby se ziskal uhel
     */
    private double koeficient = 3.60; // predpokladam ze suma hodnot == 100
    /**
     * Barva půlkruhu.
     */
    private Color[] barvy;

    /**
     * Vytvoří novou instanci třídy HalfCicle.
     */
    public Kolac(int[] cisla) {
        hodnoty = cisla;

        // vypocet koeficientu pro prepocitavani uhlu
        int sum = 0;
        for (int s : hodnoty) {
            sum += s;
        }
        koeficient = (double) 360 / sum;


        // vytvoření generátoru náhodných čísel
        Random gen = new Random();
        // Vytvoření náhodné barvy pomocí konstruktoru třídy Color,
        // jednotlivé argumenty kontruktoru jsou hondoty 0-255.
        // Metoda nextInt třídy Random vrací náhodné číslo od
        // 0 (včetně) do zadného čísla (bez).

        barvy = new Color[cisla.length];

        for (int i = 0; i < cisla.length; i++) {
            barvy[i] = new Color(
                    gen.nextInt(256),
                    gen.nextInt(256),
                    gen.nextInt(256));
        }
    }

    @Override
    protected void paintComponent(Graphics g) {
        int sirka = this.getWidth(); // šířka komponenty
        int vyska = this.getHeight(); // výška komponenty
        int x = 10; // souřadnice x pro kreslení oblouku
        int y = 10; // souřadnice y pro kreslení oblouku
        int rozmer = 0; // velikost oblouku

        super.paintComponent(g); // vymazání pozadí

        // výpočet umístění a velikosti kresleného půkruhu
        if (vyska > sirka) {
            y += (vyska - sirka) / 2;
            rozmer = sirka - 20;
        } else {
            x += (sirka - vyska) / 2;
            rozmer = vyska - 20;
        }

        // pokud je okno moc malé, nic nekresli
        if (rozmer < 10) {
            return;
        }

        int poloha = 0;
        int rest = 360;
        for (int i = 0; i < hodnoty.length; i++) {
            g.setColor(barvy[i]); // nastavení barvy kreslení

            int uhel;
            if (i < hodnoty.length - 1) {
                uhel = (int) (koeficient * hodnoty[i]);
                rest -= uhel;
            } else {
                uhel = rest;
            }
            g.fillArc(x, y, rozmer, rozmer, poloha, uhel); // vykreslení půlkruhu
            poloha += uhel;
            // první čtyři parametry určují vlastnostní obalového obdélníku celé elipsy,
            // z níž se kreslí nějaká výseč
            // pátý parametr je počáteční úhel kreslené výseče
            // šestý parametr je vnitřní úhel výseče
        }
    }
}
